#!/bin/bash

set -e

dnf upgrade -y

cat <<EOF | tee /etc/yum.repos.d/wiretrustee.repo
[Wiretrustee]
name=Wiretrustee
baseurl=https://pkgs.wiretrustee.com/yum/
enabled=1
gpgcheck=0
gpgkey=https://pkgs.wiretrustee.com/yum/repodata/repomd.xml.key
repo_gpgcheck=1
EOF

dnf install -y netbird

%{ if netbird_privatekey != "" }
mkdir -p /etc/netbird/
cat > /etc/netbird/config.json <<EOF
{
    "PrivateKey": "${netbird_privatekey}",
    "PreSharedKey": "${netbird_presharedkey}",
    "ManagementURL": {
        "Scheme": "https",
        "Opaque": "",
        "User": null,
        "Host": "api.wiretrustee.com:443",
        "Path": "",
        "RawPath": "",
        "OmitHost": false,
        "ForceQuery": false,
        "RawQuery": "",
        "Fragment": "",
        "RawFragment": ""
    },
    "AdminURL": {
        "Scheme": "https",
        "Opaque": "",
        "User": null,
        "Host": "app.netbird.io",
        "Path": "",
        "RawPath": "",
        "OmitHost": false,
        "ForceQuery": false,
        "RawQuery": "",
        "Fragment": "",
        "RawFragment": ""
    },
    "WgIface": "wt0",
    "WgPort": 51820,
    "IFaceBlackList": [
        "wt0",
        "wt",
        "utun",
        "tun0",
        "zt",
        "ZeroTier",
        "utun",
        "wg",
        "ts",
        "Tailscale",
        "tailscale",
        "docker",
        "veth",
        "br-"
    ],
    "DisableIPv6Discovery": false,
    "SSHKey": "${netbird_sshkey}",
    "SSHKey": "",
    "NATExternalIPs": null,
    "CustomDNSAddress": ""
}
EOF

systemctl enable --now netbird
%{ else }
netbird up --setup-key ${netbird_key}
%{ endif }


# Install and configure HAProxy
dnf install -y haproxy

mv /etc/haproxy/haproxy.cfg /etc/haproxy/haproxy.cfg.orig

cat <<EOF | tee /etc/haproxy/haproxy.cfg
listen smtp
    bind 0.0.0.0:25
    bind :::25
    mode tcp
    option tcplog
    log stdout format short daemon info
    timeout connect  7s
    timeout client   1m
    timeout server   1m
    server srv1-smtp smtp.k8s01.si-infra.de:10025 send-proxy-v2
listen l1
    bind 0.0.0.0:80
    bind :::80
    mode tcp
    timeout connect  4s
    timeout client   180s
    timeout server   180s
    server srv1-http ingress-proxy-protocol.k8s01.si-infra.de:80 check inter 5s send-proxy-v2
listen l2
    bind 0.0.0.0:443
    bind :::443
    mode tcp
    timeout connect  4s
    timeout client   180s
    timeout server   180s
    server srv1-https ingress-proxy-protocol.k8s01.si-infra.de:443 check inter 5s send-proxy-v2
EOF

systemctl enable --now haproxy.service

# Enable automatic updates
dnf install -y dnf-automatic

systemctl enable --now dnf-automatic-install.timer

reboot
