# The MIT License (MIT)
#
# Copyright 2021 Simon Lauger
# Copyright 2022 Christoph (Sheogorath) Kern
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

resource "hcloud_server" "server" {
  count       = var.instance_count
  name        = "${format("${var.name}%02d", count.index + 1)}.${var.dns_domain}"
  image       = var.image
  server_type = var.server_type
  keep_disk   = var.keep_disk
  ssh_keys    = var.ssh_keys
  user_data   = var.user_data
  labels      = var.labels
  datacenter    = var.datacenter
  backups     = var.backups
  public_net {
    ipv4 = element(hcloud_primary_ip.main.*.id, count.index)
  }
  lifecycle {
    ignore_changes = [firewall_ids]
  }
}

resource "hcloud_primary_ip" "main" {
  count         = var.instance_count
  name          = "${format("${var.name}%02d", count.index + 1)}.${var.dns_domain}"
  datacenter      = var.datacenter
  type          = "ipv4"
  assignee_type = "server"
  auto_delete   = false
}

resource "cloudflare_record" "dns-a" {
  count   = var.instance_count
  zone_id = var.dns_zone_id
  name    = element(hcloud_server.server.*.name, count.index)
  value   = element(hcloud_server.server.*.ipv4_address, count.index)
  type    = "A"
  ttl     = 1800
}

resource "cloudflare_record" "dns-aaaa" {
  count   = var.dns_record_aaaa ? var.instance_count : "0"
  zone_id = var.dns_zone_id
  name    = element(hcloud_server.server.*.name, count.index)
  value   = "${element(hcloud_server.server.*.ipv6_address, count.index)}1"
  type    = "AAAA"
  ttl     = 120
}

resource "hcloud_rdns" "dns-ptr-ipv4" {
  count      = var.instance_count
  server_id  = element(hcloud_server.server.*.id, count.index)
  ip_address = element(hcloud_server.server.*.ipv4_address, count.index)
  dns_ptr    = element(hcloud_server.server.*.name, count.index)
}

resource "hcloud_rdns" "dns-ptr-ipv6" {
  count      = var.instance_count
  server_id  = element(hcloud_server.server.*.id, count.index)
  ip_address = "${element(hcloud_server.server.*.ipv6_address, count.index)}1"
  dns_ptr    = element(hcloud_server.server.*.name, count.index)
}
